colour.models.dataset.ntsc_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.ntsc_rgb Module

## NTSC RGB Colourspace

Defines the NTSC RGB colourspace:

- `NTSC_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.itu.int/dms_pubrec/itu-r/rec/bt/R-REC-BT.470-6-199811-S!!PDF-E.pdf (Last accessed 13 April 2014)

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_PRIMARIES` = array([[ 0.67, 0.33], [ 0.21, 0.71], [ 0.14, 0.08]])

  NTSC RGB colourspace primaries.

  NTSC_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_WHITEPOINT` = (0.31006, 0.31616)

  NTSC RGB colourspace whitepoint.

  NTSC_RGB_WHITEPOINT : tuple

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_TO_XYZ_MATRIX` = array([[ 6.06863809e-01, 1.73507281e-01, 2.00334881e-01], [ 2.98903070e-01, 5.86619855e-01, 1.14477075e-01], [ -5.02801622e-17, 6.60980118e-02, 1.11615148e+00]])

  NTSC RGB colourspace to CIE XYZ colourspace matrix.

  NTSC_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.ntsc_rgb.` `XYZ_TO_NTSC_RGB_MATRIX` = array([[ 1.91008143, -0.53247794, -0.28822201], [-0.98463135, 1.99910001, -0.02830719], [ 0.05830945, -0.11838584, 0.89761208]])

  CIE XYZ colourspace to NTSC RGB colourspace matrix.

  XYZ_TO_NTSC_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to NTSC RGB colourspace.

  NTSC_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from NTSC RGB colourspace to linear.

  NTSC_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.ntsc_rgb.` `NTSC_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24690>

  NTSC RGB colourspace.

  NTSC_RGB_COLOURSPACE : RGB_Colourspace